@@ -1,5 +1,6 @@
 # Copyright (C) 2022 The Qt Company Ltd.
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
+from __future__ import annotations
 
 ''' Test bug 324: http://bugs.openbossa.org/show_bug.cgi?id=324'''
 
@@ -31,7 +32,7 @@ class Bug324(unittest.TestCase):
         self.value = val
 
     def testBug(self):
-        app = QCoreApplication([])
+        app = QCoreApplication([])  # noqa: F841
         bug = QBug()
         self.value = ''
         bug.done.connect(self.on_done)
